"use strict";

var _react = _interopRequireWildcard(require("react"));

var _enzyme = require("enzyme");

var _accessibility = require("../accessibility");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; return newObj; } }

var InputListComponent = (0, _accessibility.keyboardTracker)(function (props) {
  var handleKeyDown = props.handleKeyDown,
      currentFauxFocusIndex = props.currentFauxFocusIndex,
      setItemCount = props.setItemCount;
  (0, _react.useEffect)(function () {
    setItemCount(3);
  }, []);
  return _react["default"].createElement("div", null, _react["default"].createElement("input", {
    onKeyDown: handleKeyDown
  }), _react["default"].createElement("ul", null, [1, 2, 3].map(function (item, idx) {
    return _react["default"].createElement("li", {
      className: currentFauxFocusIndex === idx ? 'selected' : '',
      key: idx
    }, "Item ", item);
  })));
});
describe('utils/accessibility', function () {
  describe('#getAssistiveTextFromColorClass', function () {
    it('should throw error if non-existent class is provided', function () {
      expect(function () {
        (0, _accessibility.getAssistiveTextFromColorClass)('foo-bar');
      }).toThrow();
    });
    it('should return a word if a correct color class is provided', function () {
      expect((0, _accessibility.getAssistiveTextFromColorClass)('good-news')).toBe('Success');
    });
  });
  describe('#keyboardTracker', function () {
    var component;
    beforeEach(function () {
      component = (0, _enzyme.mount)(_react["default"].createElement(InputListComponent, null));
    });
    it('should default to index 0', function () {
      var selected = component.find('li.selected');
      expect(selected).toHaveLength(1);
      expect(selected.at(0).text()).toBe('Item 1');
    });
    it('should track ArrowDown and ArrowUp keys', function () {
      component.find('input').simulate('keydown', {
        key: 'ArrowDown'
      });
      var selected = component.find('li.selected');
      expect(selected).toHaveLength(1);
      expect(selected.at(0).text()).toBe('Item 2');
    });
    it('should limit key tracking to the size of the list', function () {
      // Simulate arrow key'ing all the way down, then all the way back up
      var selected = component.find.bind(component, 'li.selected');
      expect(selected().first().text()).toBe('Item 1');
      component.find('input').simulate('keydown', {
        key: 'ArrowDown'
      });
      expect(selected().first().text()).toBe('Item 2');
      component.find('input').simulate('keydown', {
        key: 'ArrowDown'
      });
      expect(selected().first().text()).toBe('Item 3');
      component.find('input').simulate('keydown', {
        key: 'ArrowDown'
      });
      component.find('input').simulate('keydown', {
        key: 'ArrowDown'
      });
      component.find('input').simulate('keydown', {
        key: 'ArrowDown'
      });
      expect(selected().first().text()).toBe('Item 3');
      component.find('input').simulate('keydown', {
        key: 'ArrowUp'
      });
      expect(selected().first().text()).toBe('Item 2');
      component.find('input').simulate('keydown', {
        key: 'ArrowUp'
      });
      expect(selected().first().text()).toBe('Item 1');
      component.find('input').simulate('keydown', {
        key: 'ArrowUp'
      });
      component.find('input').simulate('keydown', {
        key: 'ArrowUp'
      });
      component.find('input').simulate('keydown', {
        key: 'ArrowUp'
      });
      expect(selected().first().text()).toBe('Item 1');
    });
  });
});