function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useCallback, useState } from 'react';
import { noop } from 'lodash';
/**
 * Map a color class to a human readable word that explains the context of when
 * the class is used. This is helpful for screen readers.
 * @param {String} className - an OUI class
 * @returns {String} English word describing the class provided
 */

export var getAssistiveTextFromColorClass = function getAssistiveTextFromColorClass(className) {
  var classMapping = {
    'bad-news': 'Error',
    brand: 'Info',
    'good-news': 'Success',
    warning: 'Alert'
  };
  var text = classMapping[className];

  if (!text) {
    throw new Error('Provided class name does not map to a word.');
  }

  return text;
};
/**
 * HOC that provides support for tracking keyboard actions inside an
 * element with an input. Tracks up & down arrow keys and invokes
 * a callback when enter is pressed.
 * @param {React.Component} Component - The component to wrap.
 * @returns {React.Component}
 */

export var keyboardTracker = function keyboardTracker(Component) {
  var wrappedComponent = function wrappedComponent(props) {
    var _useState = useState(0),
        _useState2 = _slicedToArray(_useState, 2),
        currentFauxFocusIndex = _useState2[0],
        setIndex = _useState2[1];

    var _useState3 = useState(0),
        _useState4 = _slicedToArray(_useState3, 2),
        currentItemCount = _useState4[0],
        setItemCount = _useState4[1];

    var _useState5 = useState(function () {
      return noop;
    }),
        _useState6 = _slicedToArray(_useState5, 2),
        onItemSelect = _useState6[0],
        setOnItemSelect = _useState6[1];
    /**
     * Event handler for keyboard activity.
     * Increments/decrements the current index on up/down arrow keys
     *  -or-
     * Invokes the onItemSelect callback on enter
     */


    var handleKeyDown = useCallback(function (event) {
      var newIndex;

      switch (event.key) {
        case 'ArrowUp':
          newIndex = Math.max(currentFauxFocusIndex - 1, 0);
          setIndex(newIndex);
          event.preventDefault();
          break;

        case 'ArrowDown':
          newIndex = Math.max(Math.min(currentFauxFocusIndex + 1, currentItemCount - 1), 0);
          setIndex(newIndex);
          event.preventDefault();
          break;

        case 'Enter':
          // Select the item for currentFauxFocusIndex
          onItemSelect(currentFauxFocusIndex);
          event.preventDefault();
          break;

        default:
          // No op
          break;
      }
    }, [currentFauxFocusIndex, currentItemCount, onItemSelect]);
    /**
     * Handler to update the item count, which should reset the
     * current index to 0 if the number has changed.
     */

    var handleSetItemCount = useCallback(function (count) {
      setItemCount(count);

      if (count !== currentItemCount) {
        setIndex(0);
      }
    }, [currentItemCount]);
    return React.createElement(Component, _extends({}, props, {
      currentFauxFocusIndex: currentFauxFocusIndex,
      handleKeyDown: handleKeyDown,
      setItemCount: handleSetItemCount,
      setOnItemSelect: setOnItemSelect
    }));
  };

  wrappedComponent.displayName = "withkeyboardTracker(".concat(Component.displayName, ")");
  return wrappedComponent;
};